@@ -51,17 +51,35 @@ function(temp,  dt, pmolabs=c("Vertical", "North", "East"), STAMP="", baz=0 )
 
     
     buttons = rowBUTTONS(labs, col=colabs, pch=pchlabs)
+      zloc = list(x=NULL, y=NULL)
+    sloc = zloc
+
     
-     iloc = ilocator(1, COL=rgb(1,0.8, 0.8), NUM=FALSE , YN=1, style=-1)
-  zloc = iloc
-   Nclick = length(iloc$x)
-  zenclick =  length(zloc$x)
-  if(is.null(zloc$x)) { return(NULL) }
-      K = whichbutt(iloc ,buttons)
-      sloc = zloc
-   
     while(TRUE)
       {
+
+  iloc = ilocator(1, COL=rgb(1,0.8, 0.8), NUM=FALSE , YN=1, style=0)
+           Nclick = length(iloc$x)
+           
+          if(Nclick>0)
+            {
+              zloc  = list(x=c(zloc$x,iloc$x), y=c(zloc$y, iloc$y))
+              zenclick = length(zloc$x)
+              K =  whichbutt(iloc ,buttons)
+              sloc = zloc
+            }
+          else
+            {
+              Nclick = 0
+              K = 0
+              buttons = rowBUTTONS(labs, col=rep(grey(.8), length(labs)), pch=rep("NULL", length(labs)))
+              title("Return to Calling Program")
+              break;
+            }
+     
+
+
+        
         if(K[Nclick] == match("DONE", labs, nomatch = NOLAB))
           {
             break;
@@ -192,9 +210,7 @@ function(temp,  dt, pmolabs=c("Vertical", "North", "East"), STAMP="", baz=0 )
           }
 
 
-              #######  source("drivers.R"); save.image()
-
-        
+           
         if(K[Nclick]==match("More", labs, nomatch = NOLAB))
           {
            
@@ -215,25 +231,6 @@ function(temp,  dt, pmolabs=c("Vertical", "North", "East"), STAMP="", baz=0 )
              zloc = list(x=NULL, y=NULL) 
           }
 
-       
-     
-        iloc = ilocator(1, COL=rgb(1,0.8, 0.8), NUM=FALSE , YN=1, style=-1)
-        Nclick = length(iloc$x)
-
-        if(Nclick>0)
-          {
-            zloc  = list(x=c(zloc$x,iloc$x), y=c(zloc$y, iloc$y))
-            zenclick = length(zloc$x)
-              K =  whichbutt(iloc ,buttons)
-          }
-        else
-          {
-            Nclick = 0
-
-            K = 0
-            
-          }
-     
       }
 
     print("DONE with PMOT")
